bibliotheca Augustana

<<< Übersicht <<< vorige Seite nächste Seite >>>
BIBLIOTHECA AUGUSTANA

Das Nibelungenlied

1190/1200

| # Handschrift C ## 12. Aventiure
___________________________________________________ #### Auentv wie Gvnther Sivriden vn– Chriemh' ze Wormze #### mit bete brahte da man in ovch sit erslvoch [28r]
| ### Nv> daht ovch alle cite daz Gvntheres wip ### wie treit et also hohe <Chriemhilt> den lip ### nv ist doch vnser eigen Sivrit ir man ### daz er vns niht endienet des wolde ich gerne ein ende han ### Diz trvoch si in ir hercen vn– wart doch wol verdeit ### daz si ir so vremde warrn daz was der frowen leit ### daz si niht zinses hete von des fursten lant ### wa von daz chomen wære daz het si gerne bechant
###### 733 | ### Si versvchtez manigen ende ob chunde daz geschehn ### daz si Chriemh' mohte noch gesehn ### si reitez heinliche des si da hete mvot ### done duht den chunic riche der frowen bete niht zegvot
###### 734 | ### Wie chunden wir si bringen sprach der lobes rich ### her zvo disen landen daz wære vnmvgelich ### si sint vns gar <ze> verre ich getar sis niht gebiten ### des antwrt im Prvnh' in vil listigen siten
| ### Swie hohe riche wære deheines kuniges man ### swaz im gebvte sin herre wie torster daz verlan ### des ersmielte Gvnther do si daz gesprach ### ern iach sin niht ze dienste swie dicker Sivriden sach
###### 736 | ### Si sprach vil lieber herre dvrch den willen min ### so hilf mir daz noch Sivrit mit der swester din ### chom zv disem lande daz wir si hie gesehn ### sone chunde mir zer werlde nimmer lieber geschehn
###### 737 | ### Diner swester gvete vn– ir vil zvhtich <mvot> ### als ih daran gedenche wie sanfte mir daz tvot ### vn– ir vil wert enpfahen do ich chom in daz lant ### ez enwart nie antphanc richer zer welde niemen bechant
###### 738 | ### Si gertes also lange vnz daz der chunic sprach ### ir mvget mich sanfte vlegen wand ich gerner nie gesach ### deheiner slahte geste in den landen min ### ich wil in boten senden daz si zvns komen an den Rin
| ### Do sprach div chuniginne nv svlt ir mir sagn ### wenne ir si welt besenden oder in welhen tagn ### svln vnser frivnde chomen in daz lant ### die ir dar senden wellet die lat werden mir bechant
###### 740 | ### Daz tvn ich sprach do Gunther drizech miner man ### wil ich dar lazen riten die hiezer fvr sich gan ### bi den enbot er mære in Sivrides lant ### ze liebe gab in Prvnh' vil harte zierlich gewant
###### 741 | ### Do sprach do Gvnther ir rechen ir svlt sagen ### swaz ich bi iv enbiete des svlt ir niht verdagen ### Sivrit mine friunde vn– ovch die swester min ### daz enchan in der <werlde> niemen holder gesin
###### 742 | ### Vn– bite si von vns beiden leisten ane strit ### daz si chomen rvchen zvnser hochgecit ### gein disen svnewenden sol er mit sinen man ### sehen hie vil <manigen> der im vil grozer eren gan
###### 743 | ### Sime vater Sigemunde sagt ovch den dienest min ### daz ich mit minen magen im immer wæge sin ### vn– saget ovch miner swester daz si niht laze daz ### sine chom zir frivnde irn gezam nie hocgeciten baz
| ### Frov Vote vn– al die <frowen> die man [28v]ze hove vant ### enbuten ovch ir dienest in Sivrides lant ### den minneklichen meiden vn– manigem chvnem man ### Gere der vil chune sich hvop mit den <mæren> dan
###### 745 | ### Si fvren reisliche ir pfærit vn– ir gewant ### daz was in chomen allen do rvomten si daz lant ### in zovgte wol der reise dar si da solden varn ### der kunic mit geleite bat die boten wol bewarn
###### 746 | ### Inre tagn zwelfen si chomen in daz lant ### ze Nibelunges burge dar warn si gesant ### da vunden si mit frevden den vil chvnen degn ### div ross den boten waren mvede von den langen wegn
###### 747 | ### Dem kunige vn– sime wibe wart zehant geseit ### in wærn chomen geste die trvgen solhiv chleit ### als man zen Burgonden do der site pflach ### Chriemh' spranch von dem bette daran si bi ir liebe lach
| ### Si bat an ein venster ir mægede eine gen ### div sach den chunen Geren an dem hove sten ### mit sinen hergesellen die warn dar gesant ### gein ir herceleide wie <liebiv> mare si bevant
###### 749 | ### Si sprach zv dem kvnige ir svlt vf sten ### ieh sihe den starchen Geren her ze hove gen ### in hat min brvder Gunther wætlich her gesant ### waz der reche werbe daz het ich gerne bechant
###### 750 | ### Allez daz gesinde dar lief vn– gie ### in vil grozen vrevden man die geste enpfie ### vn– taten in daz beste daz si chunden do ### wande si ir chunfte in ir hercen warn vro
###### 751 | ### Gere wol enpfangen wart mit sinen man ### ir ross man hiez behalten die helde braht man dan ### da der herre Sivrit bi Chriemh' saz ### si sahen in vil gerne daz svlt ir wizzen ane haz
###### 752 | ### Gegen den lieben gesten si stvnden vf zehant ### wol wart <enpfangen> Gere von Buregonden lant ### vn– sine hergesellen bi der hende dan ### Chriemh' fvorte Geren daz wart dvrch liebe getan
| ### Si bat in zvozir sizzen er sprach wir suln sten ### erlovbet vns die boteschaft e daz wir sizzen gen ### vn– horet disiv mære waz iv enboten hat ### Gvnther vn– Prunh' der dinc an eren hohe stat
###### 754 | ### vn waz iv iwer mvoter min frowe her enbot ### Giselher der iunge vn– ovch Gernot ### vn– iwer besten mage die hant vns her gesant ### vn– enbietent iv ir dienest vzer Burgonden lant
###### 755 | ### Nv lon in got sprach Sivrit ich getrow in allen wol ### triwen vn– gvotes also man frivnden sol ### daz selbe tvot ir swester wie <si> gehabn sich ### die unsern lieben frivnde daz sult ir lazen horen mich
###### 756 | ### Sit daz wir von in schieden hat ieman iht getan ### den minen chonemagen daz lazet mich verstan ### daz wil ich in mit triwen immer helfen tragen ### vnze daz ir viende den minen dienest mvzen klagen
| ### Do sprach der marcgraue Gere ein reche gvot ### si sint in allen tvgenden mit frevden wol gemvot ### si ladent ivch ze [29r]Rine zeiner hochgecit ### wande si ivch gerne sæhen daz ir des ane zwifel sit
###### 758 | ### Vn– bitent mine frowen si svln mit iv chomen ### swenne so der winder ein ende habe genomen ### gein disen svnewenden so wolden si ivch sehen ### do sprach der herre Sivrit daz chunde mvelich geschehn
###### 759 | ### Do sprach aber Gere voz Buregonden lant ### iwer mvoter Vote div hat ivch gemant ### vn– iwer brveder beide ir svlt in niht versagen ### daz ir in sit so verre daz hoere ich si vil dicke klagen
###### 760 | ### Prvnh' min vrowe vn– alle ir magedin ### die froewent sich der gegene ob daz chunde sin ### daz si ivch gesehen noch so si des habent mvot ### da dvhten disiv mære die schonen Chriemh' gvot
| ### Gere was ir sippe der wirt in sizzen hiez ### den gesten hiez man schenchen niht langer man daz liez ### do was ovch chomen Sigemvont do er die boten sach ### der herre minnekliche zv den Burgonden sprach
###### 762 | ### Sit willechomen ir <rechen> ir Gvntheres man ### sit Chriemhilde ze <man> minen svon gewan ### so solde man ivch degene dicker bi vns sehn ### ob ir vns mit triwen woldet frivntschefte iehn
###### 763 | ### Si sprachen swenner wolde si solden gerne chomen ### in wart ir michel mvede mit frevden vil benomen ### die boten bat man sizzen spise man in trvoch ### der wart den lieben gesten gegebn volleklich genvoch
###### 764 | ### Man gab in herberge vn– schvf in gvot gemach ### der herre zv den gesten minneklichen sprach ### lat ivch niht betragen darvmbe ir sit gesant ### her von vnsern friunden wir svlenz iv schiere tvon bechant
###### 765 | ### Ich mvoz mihs noch beraten mit den <friunden> min ### er gie zeiner sprache mit den rechen sin ### er sprach min frivnt Gunther hat nach vns gesant ### zeiner hochgecite nv ist ze verre mir sin lant
###### 766 | ### Vn– bitent mine frowen daz si mit var ### nv ratent liebe vriunde wie sol si chomen dar ### vn– solde ich herverten durch si in drizech lant ### da mvse in gerne dienen hin div Sivrides hant
| ### Do sprachen sine rechen habt ir der reise mvot ### so wellen wir iv raten daz iv wirdet gvot ### ir svlt mit tvsint rechen riten an den Rin ### so mvgt ir wol mit eren da zer hochgecite sin
###### 768 | ### Do sprach von Niderlanden der herre Sigemvnt ### welt ir zir hochgecite wan tvot ir mir daz kunt ### ob ez iv niht versmahet so rite ich mit iv dar ### vn– bringe iv hundert degene da mit mer ich iwer schar
###### 769 | ### Sit ir welt mit uns riten vil lieber vater min ### sprach der herre Sivrit vro sol ich des sin ### inre tage zwelfen so rvom ich miniv lant ### die si do furen wolden den gap man ross vn– ovch gewant
| ### Do der chunic edele der reise hete mvot ### do hiez man wider riten die snellen boten gvot ### den sinen chonemagen enbot er an den Rin ### daz er gerne wolde [29v]da zir hochgecite sin
###### 771 | ### Sivrit vn– Chriemh' als wir horen sagen ### so vil den boten gaben daz ez niht mohten tragen ### ir moere heime ze lande er was ein richer man ### ir starchen sovmære si triben vrolichen dan
###### 772 | ### Ir volche daz <kleite> Sivrit vn– ovch Sigemvnt ### Ecgewart der graue der hiez do an der stvnt ### frowen chleider svochen die besten die man vant ### oder iemen vinden chvnde vber allez Sivrides lant
###### 773 | ### Sætil vn– schilde bereiten man began ### rittern vn– frowen die mit im wolden dan ### den gab man swaz si wolden wie wenich in gebrast ### do brahter sinen frivnden manigen herlichen gast
| ### Den boten zogete sere wider vf den wegn ### do chome wol ze lande Gere der degen ### er wart vil wol enpfangen do stvnden si zetal ### nider von den moeren fvr den Guntheres sal
###### 775 | ### Der chunic durch groze liebe vorn dem sedele spranch ### daz so snelle chomen des bat si haben danch ### Prunhilt div schone der kunich zen boten sprach ### wie vert min frivnt Sivrit von dem mir liebes vil geschach
###### 776 | ### Do sprach der chune Gere da wart er frevden rot ### er vn– iwer swester nie frivnden baz enbot ### so frivntlicher mære deheiner slahte man ### als iv der herre Sivrit vn– ovch sin vater hat getan
###### 777 | ### Do sprach zem marcgrauen des edeln kuniges wip ### nv sagt mir chvmet Chriemhilt hat noch ir schoner lip ### behalten iht der zvehte der si wol chunde pflegen ### er sprach si choment beide vn– mit in manic <kuner> degn
| ### Frov Vote bat do drate die boten zvo zir gen ### daz mac man an ir vrage harte wol versten ### daz si vil gerne horte was Chriemh' noch gesunt ### er sagete wie er funde vn– daz si chome in churzer stunt
###### 779 | ### Ovch wart von in div gabe ze hove niht verdeit ### die in dort gab Sivrit golt <silber> vn– kleit ### daz brahte man ze sehene der drier kunige man ### der ir vil grozen milte wart in do <danchens> vil getan
###### 780 | ### Er mac wol gebn ringe sprach Hagene der degn ### ern chundez niht verswenden vn– solt er immer lebn ### hort der Nibelunge beslozzen hat sin hant ### hey solden wir den teilen noch in Buregonden lant
###### 781 | ### Allez daz gedigene frevte sich der zvo ### daz si chomen solden spate vn– frvo ### warn vil vnmvzich des fursten ambtman ### waz richer hergesidele man da rihten began
| ### Ortwin vn– Sindolt die zwene chune degn ### die warn vil vnmvezich die zit si mvosin pflegen ### der trvhsezze vn– der schenche rihten manigen banch ### des hulfen ir vndertanen des sagete in Gvnther do danch
###### 783 | ### Rvomolt der chuchenmeister vil wol berihte sit ### die sinen vndertanen vil manigen kezzil wit ### hæfene vn– pfannen hey waz man der da vant ### do bereite man den spise die da chomen in daz lant [30r]
###### 784 | ### Der frowen arebeiten was ovch niht kleine ### da si bereiten ir chleider die edeln steine ### mit glanze verre glesten verwieret in daz golt ### do si sie ane leiten daz in die lute wrden holt

<<< Übersicht <<< vorige Seite nächste Seite >>>